==> distribution-6.0.0-dev.128.zip: drr/regulation/common/validation/exists/ValuationDetailsOnlyExistsValidator.java <==
package drr.regulation.common.validation.exists;

import cdm.event.common.Valuation;
import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidationResult.ValidationType;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.regulation.common.ValuationDetails;
import drr.regulation.common.ValuationTradeInformation;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class ValuationDetailsOnlyExistsValidator implements ValidatorWithArg<ValuationDetails, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends ValuationDetails> ValidationResult<ValuationDetails> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("valuation", ExistenceChecker.isSet((Valuation) o.getValuation()))
				.put("tradeInformation", ExistenceChecker.isSet((ValuationTradeInformation) o.getTradeInformation()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("ValuationDetails", ValidationType.ONLY_EXISTS, "ValuationDetails", path, "");
		}
		return failure("ValuationDetails", ValidationType.ONLY_EXISTS, "ValuationDetails", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}

==> distribution-7.0.0-dev.17.zip: drr/regulation/common/validation/exists/ValuationDetailsOnlyExistsValidator.java <==
package drr.regulation.common.validation.exists;

import cdm.event.common.Valuation;
import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.regulation.common.ValuationDetails;
import drr.regulation.common.ValuationTradeInformation;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class ValuationDetailsOnlyExistsValidator implements ValidatorWithArg<ValuationDetails, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends ValuationDetails> ValidationResult<ValuationDetails> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("valuation", ExistenceChecker.isSet((Valuation) o.getValuation()))
				.put("tradeInformation", ExistenceChecker.isSet((ValuationTradeInformation) o.getTradeInformation()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("ValuationDetails", ValidationResult.ValidationType.ONLY_EXISTS, "ValuationDetails", path, "");
		}
		return failure("ValuationDetails", ValidationResult.ValidationType.ONLY_EXISTS, "ValuationDetails", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}
